---
title: "Crypto Trading with AG2 - Jan 23, 2025"
---

### Speakers: Pranav Prakash

### Biography of the speakers:

Pranav Prakash is the co founder & cto at FereAI - a crypto research platform, with its swarm of agents. FereAI’s mission is to empower everyone with pro tools to make better trading, investment decisions at affordable prices. Pranav combines his experience of AI, MLOps, crypto & consumer apps to build products that are simple yet powerful. Previously, Pranav cofounded Quartic.ai - an autonomous Industrial AI platform being used in Fortune 500 companies in pharma & life sciences sector. Before Quartic, he co founded Octo.ai. Pranav was also working on search and recommendations at LinkedIn, Slideshare. He has been speaking about AI, Crypto & Python at various events.

### Abstract:

Crypto trading is a multi dimensional 24x7 engagement. With so many tokens launching every day and so much of research to be done for each token, it becomes difficult for an average person or full time trader to perform successful trades and to keep a track of their portfolio and rebalance them as and when the market dynamics shift. In order to solve for this, we created 0xMONK - an autonomous trading agent. This agent takes broad instructions from user on the kind of trades to be done and then monitors the new newly launched tokens and the trending tokens in real time and perform research on them and then makes decisions on whether to buy, sell, hold or pass the tokens. In this talk, we will explore the architecture and underlying principles of 0xMONK. We will see how AG2 framework is leveraged in creating it.
